% Class: CMSslides.cls
%
% Home-brewed style file for slides, based on the "seminar" package
% by Timoty van Zandt; have a look at the documentation available for
% the above package, e.g. under the URLs:
%
%    http://wwwcdf.pd.infn.it/localdoc/seminar.ps.gz
%    http://wwwcdf.pd.infn.it/localdoc/seminar_faq.ps.gz
%
% $Id: CMSslides.cls,v 1.5 2005/03/14 10:45:42 loreti Exp $
%
% Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
% Work:   University of Padova - Department of Physics
%         Via F. Marzolo, 8 - 35131 PADOVA - Italy
% Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
% EMail:  loreti@pd.infn.it
% WWW:    http://www.pd.infn.it/~loreti/mlo.html

\NeedsTeXFormat{LaTeX2e}
\ProvidesPackage{CMSslides} [2005/03/14 MLO's CMS slides setup]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{seminar}}
\ProcessOptions
\LoadClass{seminar}

% Other packages

\RequirePackage[dvips]{color}
\RequirePackage[dvips]{graphicx}
\RequirePackage{amssymb}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{semcolor}
\RequirePackage{fancyhdr}

% Input corrections to 'seminar'

\input{seminar.bug}
\input{seminar.bg2}

% Slides parameters: general setup

\centerslidesfalse              % Text not centered
\slideframe{none}               % No frame borders
\raggedslides[2em]              % Semi-ragged-right text
\slidestyle{empty}              % No labels
\rotateheaderstrue              % Header and slide orientation synchronized

% Slides dimensions and header placement

\renewcommand{\slidetopmargin}{30mm}
\renewcommand{\slidebottommargin}{76bp}

% To horizontally center headers and footers (see file
% "seminar.bug")

\renewcommand{\headwidth}{\textwidth}

% Landscape printing sequence (for dvips)

\renewcommand{\printlandscape}{\special{landscape}}

% Some frequently used custom colors

\definecolor{AliceBlue}{rgb}{0.94,0.97,1}
\definecolor{Black}{rgb}{0,0,0}
\definecolor{Blue}{rgb}{0,0,1}
\definecolor{Blue2}{rgb}{0,0,0.93}
\definecolor{DarkSlateGray}{rgb}{0.18,0.31,0.31}
\definecolor{FireBrick}{rgb}{0.7,0.13,0.13}
\definecolor{Gold}{rgb}{1,0.84,0}
\definecolor{Green}{rgb}{0,1,0}
\definecolor{Green3}{rgb}{0,0.8,0}
\definecolor{Magenta2}{rgb}{0.82,0,0.82}
\definecolor{NavyBlue}{rgb}{0,0,0.5}
\definecolor{Purple2}{rgb}{0.57,0.17,0.93}
\definecolor{Red}{rgb}{1,0,0}
\definecolor{SaddleBrown}{rgb}{0.55,0.27,0.07}
\definecolor{Yellow}{rgb}{1,1,0}

% New commands for slide titles:
% - defines a variable "\theSlideTitle" to be printed as
%   top-center header, initialized to nothing;
% - defines a command "\slideTitle" that changes the content
%   of the above variable.

\newcommand{\theSlideTitle}{\relax}
\newcommand{\slideTitle}[1]{\renewcommand{\theSlideTitle}{#1}}

% Slide headers:
% - top left: the CMS logo
% - top center: \theSlideTitle
% - top right: seal of the University of Padova
% - bottom: nothing.

\fancyhf{}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\fancyhead[L]{\includegraphics[width=10mm]{cms_logo.eps.gz}}
\fancyhead[C]{\theSlideTitle}
\fancyhead[R]{\includegraphics[width=10mm]{bo.eps.gz}}

% Redefine the indentation of the (left adjusted by [fleqn])
% equations

\makeatletter
\setlength{\@mathmargin}{1.2em}
\makeatother

% Reset \ldots to the default, overriding the redefinition in
% amsmath.sty.

\DeclareRobustCommand{\ldots}{\ifmmode\mathellipsis\else\textellipsis\fi}

% Space adjustment for tables (thanks to Claudio Beccari)

\newcommand{\tabtop}{\rule{0pt}{2.6ex}}
\newcommand{\tabbot}{\rule[-1.2ex]{0pt}{0pt}}

% My itemize environment; the general definition, and three predefined
% cases.

\newenvironment{myt}[1]{\begin{list}{#1}
    {\setlength{\itemindent}{0pt}%
      \settowidth{\labelwidth}{#1}%
      \setlength{\labelsep}{0.4em}%
      \setlength{\leftmargin}{\labelwidth}%
      \setlength{\rightmargin}{0pt}%
      \setlength{\listparindent}{0pt}%
      \addtolength{\leftmargin}{\labelsep}%
      \setlength{\topsep}{0pt}%
      \setlength{\parsep}{0pt}%
      \setlength{\partopsep}{\parskip}%
      \setlength{\itemsep}{0pt}}}%
  {\end{list}}

\newenvironment{myt0}{\begin{myt}{$\bullet$}}{\end{myt}}

\newenvironment{myt1}{\begin{myt}{$\star$}}{\end{myt}}

\newenvironment{myt2}{\begin{myt}{$\triangleright$}}{\end{myt}}

\newenvironment{myt3}{\begin{myt}{$\rhd$}}{\end{myt}}

\endinput

%%
%% End of `CMSslides.cls'
