% Class: MLOslides.cls
%
% Home-brewed style file for slides, based on the "seminar" package
% by Timoty van Zandt; have a look at the documentation available for
% the above package, e.g. under the URLs:
%
%    http://wwwcdf.pd.infn.it/localdoc/seminar.ps.gz
%    http://wwwcdf.pd.infn.it/localdoc/seminar_faq.ps.gz
%
% Instructions:
%
% 1) Put a \documentclass[options]{MLOslides} as class declaration for
%    your document; "options" is a list of, well, options to be passed
%    to "seminar": e.g., you may want to use something like:
%
%    \documentclass[a4,portrait]{MLOslides}
%
% 2) "MLOslides" includes for you the following packages: "color";
%    "graphicx"; "amsmath"; "amssymb"; "paralist".  You may want to
%    add after the \documentclass other packages you need, e.g.
%
%    \usepackage[italian]{babel}
%
% 3) "MLOslides" defines the following new commands and environments:
%
%    - \slideTitle: a command to define a title to be printed in a
%      box, to be used e.g. like:
%
%      \slideTitle{The title of this slide}
%
%      - a compact itemize-like environment, "myt", defined through the
%        package "paralist".  To be invoked e.g. like:
%
%      \begin{myt}{$\bullet$}
%      \item ...
%      \item ...
%      \end{myt}
%
%    - a new page style, "slidata", valid both for landscape- and
%      portrait-oriented slides; to be used e.g. with
%
%      \pagestyle{slidata}
%
%      "slidata" uses three internal commands: \presTitle, \presAuthor
%      and \presStyle.  The first two (the "presentation title" and
%      the "author name") *MUST* be defined by the user with
%      \newcommand; the third one is already defined as a do-nothing
%      command, and *MAY* be REdefined with \renewcommand e.g. in
%      order to change the fonts used for presentation title, author
%      name and slide number (that command is used right before these
%      printouts).  Example:
%
%      \newcommand{\presTitle}{How I discovered the Higgs boson}
%      \newcommand{\presAuthor}{Maurizio Loreti}
%      \renewcommand{\presStyle}{\bold}
%
% $Id: MLOslides.cls,v 1.6 2006/02/24 09:33:54 loreti Exp $
%
% Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
% Work:   University of Padova - Department of Physics
%         Via F. Marzolo, 8 - 35131 PADOVA - Italy
% Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
% EMail:  loreti@pd.infn.it
% WWW:    http://www.pd.infn.it/~loreti/mlo.html

\NeedsTeXFormat{LaTeX2e}
\ProvidesPackage{MLOslides} [2006/02/24 MLO's slides setup]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{seminar}}
\ProcessOptions
\LoadClass{seminar}

\newcommand{\presStyle}{\relax}

% Other packages

\RequirePackage[dvips]{color}
\RequirePackage[dvips]{graphicx}
\RequirePackage{amssymb}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{semcolor}
\RequirePackage{paralist}

% Input corrections to 'seminar'

\input{seminar.bug}
\input{seminar.bg2}

% Slides parameters: general setup

\centerslidesfalse              % Text not centered
\slideframe{none}               % No frame borders
\raggedslides[2em]              % Semi-ragged-right text
\slidestyle{empty}              % No labels
\rotateheaderstrue              % Header and slide orientation synchronized

% Slides dimensions and header placement

\addtolength{\slidewidth}{25mm}
\addtolength{\slideheight}{15mm}
\renewcommand{\slideleftmargin}{10mm}
\renewcommand{\sliderightmargin}{10mm}
\renewcommand{\slidetopmargin}{10mm}
\renewcommand{\slidebottommargin}{15mm}
\renewcommand{\slidefuzz}{20pt}

% Landscape printing sequence (for dvips)

\renewcommand{\printlandscape}{\special{landscape}}

% Some frequently used custom colors

\definecolor{AliceBlue}{rgb}{0.94,0.97,1}
\definecolor{Black}{rgb}{0,0,0}
\definecolor{Blue}{rgb}{0,0,1}
\definecolor{Blue2}{rgb}{0,0,0.93}
\definecolor{DarkSlateGray}{rgb}{0.18,0.31,0.31}
\definecolor{FireBrick}{rgb}{0.7,0.13,0.13}
\definecolor{Gold}{rgb}{1,0.84,0}
\definecolor{Green}{rgb}{0,1,0}
\definecolor{Green3}{rgb}{0,0.8,0}
\definecolor{Magenta2}{rgb}{0.82,0,0.82}
\definecolor{NavyBlue}{rgb}{0,0,0.5}
\definecolor{Purple2}{rgb}{0.57,0.17,0.93}
\definecolor{Red}{rgb}{1,0,0}
\definecolor{SaddleBrown}{rgb}{0.55,0.27,0.07}
\definecolor{Yellow}{rgb}{1,1,0}

% A new command for boxed slide titles

\newlength{\titlelength}
\newcommand{\slideTitle}[1]{%
  \setlength{\titlelength}{0.8\linewidth}%
  \begin{center}\psshadowbox[linecolor=NavyBlue,
    shadowcolor=NavyBlue,
    shadowsize=4pt,
    fillstyle=solid,
    fillcolor=AliceBlue,
    framesep=7pt,
    framearc=0.3]{%
      \begin{minipage}{\titlelength}%
        \begin{center}\color{Blue2}\bfseries#1\end{center}%
      \end{minipage}}%
  \end{center}\par\vspace{10mm}}

% Redefine the indentation of the (left adjusted by [fleqn])
% equations

\makeatletter
\setlength{\@mathmargin}{1.2em}
\makeatother

% Reset \ldots to the default, overriding the redefinition in
% amsmath.sty.

\DeclareRobustCommand{\ldots}{\ifmmode\mathellipsis\else\textellipsis\fi}

% Space adjustment for tables (thanks to Claudio Beccari)

\newcommand{\tabtop}{\rule{0pt}{2.6ex}}
\newcommand{\tabbot}{\rule[-1.2ex]{0pt}{0pt}}

% Compact itemize environments, defined through the package "paralist"

\newenvironment{myt}[1]{\begin{compactitem}[#1]}{\end{compactitem}}

\newenvironment{myt0}{\begin{compactitem}[$\bullet$]}{\end{compactitem}}

\newenvironment{myt1}{\begin{compactitem}[$\star$]}{\end{compactitem}}

\newenvironment{myt2}{\begin{compactitem}[$\triangleright$]}{\end{compactitem}}

\newenvironment{myt3}{\begin{compactitem}[$\rhd$]}{\end{compactitem}}

% Slide headers: landscape and portrait without watermark (slidata).

\newpagestyle{slidata}{\color{Gold}\rule{10mm}{1.5pt}%
  \lower.25ex\hbox{\color{FireBrick}\kern4pt{\presStyle\presTitle}\kern4pt}%
  \leavevmode\leaders\hrule height1.5pt\hfil}
{\color{Gold}\rule{5mm}{1.5pt}%
  \lower.25ex\hbox{\color{FireBrick}\kern4pt{\presStyle\presAuthor}\kern4pt}%
  \leavevmode\leaders\hrule height1.5pt\hfil%
  \lower.5ex\hbox{\color{FireBrick}\kern4pt{\presStyle\thepage}\kern4pt}%
  \rule{5mm}{1.5pt}}

\endinput

%%
%% End of `MLOslides.cls'
