% Class: UNINFN.cls
%
% Home-brewed style file for slides, based on the "seminar" package
% by Timoty van Zandt; have a look at the documentation available for
% the above package, e.g. under the URLs:
%
%    http://wwwcdf.pd.infn.it/localdoc/seminar.ps.gz
%    http://wwwcdf.pd.infn.it/localdoc/seminar_faq.ps.gz
%
% $Id: UNINFN.cls,v 1.2 2005/03/14 10:45:42 loreti Exp $
%
% Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
% Work:   University of Padova - Department of Physics
%         Via F. Marzolo, 8 - 35131 PADOVA - Italy
% Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
% EMail:  loreti@pd.infn.it
% WWW:    http://www.pd.infn.it/~loreti/mlo.html

\NeedsTeXFormat{LaTeX2e}
\ProvidesPackage{UNINFN}[2005/03/14 MLO's Uni+INFN slides setup]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{seminar}}
\ProcessOptions
\LoadClass{seminar}

% Other packages

\RequirePackage[dvips]{color}
\RequirePackage[dvips]{graphicx}
\RequirePackage{amssymb}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{semcolor}
\RequirePackage{fancyhdr}

% Input corrections to 'seminar'

\input{seminar.bug}
\input{seminar.bg2}

% Slides parameters: general setup

\centerslidesfalse              % Text not centered
\slideframe{none}               % No frame borders
\raggedslides[2em]              % Semi-ragged-right text
\slidestyle{empty}              % No labels
\rotateheaderstrue              % Header and slide orientation synchronized

% Slides dimensions and header placement

\renewcommand{\slideleftmargin}{10mm}
\renewcommand{\sliderightmargin}{10mm}
\renewcommand{\slidetopmargin}{35mm}
\renewcommand{\slidebottommargin}{15mm}
\renewcommand{\slidefuzz}{20pt}
\renewcommand{\headwidth}{\textwidth}

% Landscape printing sequence (for dvips)

\renewcommand{\printlandscape}{\special{landscape}}

% Some frequently used custom colors

\definecolor{AliceBlue}{rgb}{0.94,0.97,1}
\definecolor{Black}{rgb}{0,0,0}
\definecolor{Blue}{rgb}{0,0,1}
\definecolor{Blue2}{rgb}{0,0,0.93}
\definecolor{DarkSlateGray}{rgb}{0.18,0.31,0.31}
\definecolor{FireBrick}{rgb}{0.7,0.13,0.13}
\definecolor{Gold}{rgb}{1,0.84,0}
\definecolor{Green}{rgb}{0,1,0}
\definecolor{Green3}{rgb}{0,0.8,0}
\definecolor{HoneyDew}{rgb}{0.94,1,0.94}
\definecolor{Magenta2}{rgb}{0.82,0,0.82}
\definecolor{MintCream}{rgb}{0.96,1,0.98}
\definecolor{NavyBlue}{rgb}{0,0,0.5}
\definecolor{Purple2}{rgb}{0.57,0.17,0.93}
\definecolor{Red}{rgb}{1,0,0}
\definecolor{SaddleBrown}{rgb}{0.55,0.27,0.07}
\definecolor{Yellow}{rgb}{1,1,0}

% A new command for boxed slide titles

\newlength{\headerlength}
\newcommand{\header}[1]{%
  \setlength{\headerlength}{0.7\linewidth}%
  \fancyhead[C]{%
    \raisebox{4mm}{%
      \psshadowbox[linecolor=NavyBlue, shadowcolor=NavyBlue,
      shadowsize=4pt, fillstyle=solid, fillcolor=AliceBlue,
      framesep=7pt, framearc=0.3]{%
        \begin{minipage}{\headerlength}%
          \centering{\bfseries\color{Blue2}#1}%
        \end{minipage}}}}}

% Redefine the indentation of the (left adjusted by [fleqn])
% equations

\makeatletter
\setlength{\@mathmargin}{1.2em}
\makeatother

% Reset \ldots to the default, overriding the redefinition in
% amsmath.sty.

\DeclareRobustCommand{\ldots}{\ifmmode\mathellipsis\else\textellipsis\fi}

% My itemize environment; the general definition, and three predefined
% cases.

\newenvironment{myt}[1]{\begin{list}{#1}
    {\setlength{\itemindent}{0pt}%
      \settowidth{\labelwidth}{#1}%
      \setlength{\labelsep}{0.4em}%
      \setlength{\leftmargin}{\labelwidth}%
      \setlength{\rightmargin}{0pt}%
      \setlength{\listparindent}{0pt}%
      \addtolength{\leftmargin}{\labelsep}%
      \setlength{\topsep}{0pt}%
      \setlength{\parsep}{0pt}%
      \setlength{\partopsep}{\parskip}%
      \setlength{\itemsep}{0pt}}}%
  {\end{list}}

\newenvironment{myt0}{\begin{myt}{$\bullet$}}{\end{myt}}
\newenvironment{myt1}{\begin{myt}{$\star$}}{\end{myt}}
\newenvironment{myt2}{\begin{myt}{$\triangleright$}}{\end{myt}}
\newenvironment{myt3}{\begin{myt}{$\rhd$}}{\end{myt}}

% Slide headers --- REMEMBER: INSERT A \pagestyle{fancy}
% STATEMENT RIGHT AFTER YOUR \begin{document} IN THE MAIN
% .TEX FILE .

\fancyhf{}
\fancyhead[L]{\includegraphics[height=10mm]{bo.eps}}
\fancyhead[R]{\includegraphics[height=10mm]{infnlogo.eps}}
\fancyfoot[L]{\tiny CMS week \\ 28-Nov-2003}
\fancyfoot[C]{\tiny~\\ Maurizio Loreti}
\fancyfoot[R]{\tiny How I discovered \\ the Higgs Boson}
\renewcommand{\headrulewidth}{0pt}

\endinput

%%
%% End of `UNINFN.cls'
